function test_decis = MoreSpecTest_Power(crittable,testval,rho1,rho2,kern,T,alphavec,p,k,q,b) 
%-------------------------------------------------------------------------
% function test_decis = MoreSpecTest_Power(crittable,testval,rho1,rho2,kern,T,alphavec,p,k,q,b) 
%
% Function to evaluate whether Wald-test is rejected at percentiles
% alphavec when using critical values from size corrected tables
%
% 
% Input: crittable ... table with empirical critical values
%        testval   ... Value of test statistic (vector in R^{nr. of tests
%                      \times 1})
%           rho1,rho2 ... Values of rho1, rho2
%           kern   ... Kernel function (usual abbreviation)
%              T   ... Sample size
%       alphavec   ... Vector in R^{numAlpha \times 1} with critical values
%                      considered in set: 2 times - 0.01, 0.025, 0.05
%          p       ... specifies determinstics
%          k       ... number of I(1) regressors
%          q       ... highest order for RESET test
%          b       ... specifies the bandwidth chosen,
%                      in the range (0,1]
%
% Output: 
%    test_decis ... Vector in R^{numAlpha \times 1} with rejection
%                   frequencies
%                   (0 if no rejection and 1 if rejection; per test)
%
% OS, 2013
%--------------------------------------------------------------------------
    
% Select correct plane from the 3D-matrix
if rho1 == 0.0
    rhoset = 1;
elseif rho1 == 0.3
    rhoset = 2;
elseif rho1 == 0.6
    rhoset = 3;
elseif rho1 == 0.8
    rhoset = 4;
end    

% Select the row corresponding to the test chosen: selection is equal to
if strcmp(b,'And91')==0 && strcmp(b,'NW')==0 && strcmp(b,'NWT')==0 && strcmp(b,'And91_datadep')==0 && strcmp(b,'NW_datadep')==0 && strcmp(b,'NWT_datadep')==0
    critrow = crittable(max(floor(50*b),1),:,rhoset);
else
    critrow = crittable(1,:,rhoset);
end    
[numA,sizeA2] = size(alphavec);
[numTest,SizeT2] = size(testval);
test_decis = zeros(numA,numTest);

for j = 1:numA; % Loop over different alpha-values
    
    
    % Check the used perc-vec specifications to use proper columns: 
    if alphavec(j,1) == 0.01; % Choice of critical values for spec. alpha        
        vval = critrow(9);
    elseif alphavec(j,1) == 0.025;
        vval = critrow(8);        
    elseif alphavec(j,1) == 0.05;
        vval = critrow(7);
    elseif alphavec(j,1) == 0.1;
        vval = critrow(6);
    elseif alphavec(j,1) == 0.5;
        vval = critrow(5);
    elseif alphavec(j,1) == 0.9;
        vval = critrow(4);
    elseif alphavec(j,1) == 0.95;
        vval = critrow(3);
    elseif alphavec(j,1) == 0.975;
        vval = critrow(2);
    elseif alphavec(j,1) == 0.99;
        vval = critrow(1);        
    end;
    
    % Rejection decision:
    test_decis(j,:) = (testval > vval);
    
end;

test_decis = mean(test_decis,2); % Column vector
