function wstat = TestPart_FullNL_H(thetahat,Vhat,Oudotv,thetanull,p,k)
%--------------------------------------------------------------------------
% function wstat =
% TestPart_FullNL_H(thetahat,Vhat,Oudotv,thetanull,p,k)
%
% Function to calculate the test statistics for the Full NL experiment
%
% Input:  thetahat  ... estimated theta
%         thetanull ... theta uner null
%         Vhat      ... estimated VCV
%         Oudotv    ... long-run variance
%             p     ... specifies determinstics
%                    -1 ... no deterministics
%                     0 ... only constant
%                     p ... constant + deterministics with
%                           highest order p, if p > 1
%             k     ... number of I(1) regressors                        
%
% Output:  wstat ... Wald statistic
%
% Remark:
% thetahat = [const linx liny sqx sqy crossxy [+cubic +further terms]
%
% MW, modifications by OS 2013
%-------------------------------------------------------------------------

endh = length(thetanull);

% Cut of deterministic parts:
Bhat = thetahat(k+p+2:endh,1); 
Bnull = thetanull(k+p+2:endh,1);
VhatB = Vhat(k+p+2:endh,k+p+2:endh);

% Wald statistic:
outerterm = Bhat - Bnull;
innerterm = inv(Oudotv*VhatB);
wstat = outerterm'*innerterm*outerterm;
